def check_keys(target, reference, errors, trail):
    for key in target.keys():
        trail.append(key)
        trail_string = ".".join(trail)
        if "additionalProperties" in reference.keys():
            trail.pop()
            continue
        if key not in reference["properties"].keys():
            errors.append(trail_string)
        if isinstance(target[key], dict):
            if key in reference["properties"]:
                errors = check_keys(
                    target[key], reference["properties"][key], errors, trail
                )
            else:
                errors = check_keys(target[key], reference, errors, trail)
        trail.pop()
    return errors



from setuptools import setup

from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.md")) as f:
    long_description = f.read()

setup(
    name="naislinter",
    version="1.0.3",
    license="MIT",
    url="https://github.com/chinatsu/naislinter",
    description="Lints naiserator.yaml files",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Kent Daleng",
    author_email="kent.stefan.daleng@nav.no",
    packages=["naislinter"],
    install_requires=["pyyaml", "requests"],
    scripts=["naislinter/naislinter"],
)
